# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_marketingmessages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.steammessages_storebrowse_pb2 as steammessages__storebrowse__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%steammessages_marketingmessages.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x1fsteammessages_storebrowse.proto\"`\n5CMarketingMessages_GetActiveMarketingMessages_Request\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\t\x12\x16\n\x0e\x61nonymous_user\x18\x02 \x01(\x08\"\xaf\x06\n\x16\x43MarketingMessageProto\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\r\n\x05title\x18\x02 \x01(\t\x12@\n\x04type\x18\x03 \x01(\x0e\x32\x16.EMarketingMessageType:\x1ak_EMarketingMessageInvalid\x12P\n\nvisibility\x18\x04 \x01(\x0e\x32\x1c.EMarketingMessageVisibility:\x1ek_EMarketingMessageVisibleBeta\x12\x10\n\x08priority\x18\x05 \x01(\r\x12]\n\x10\x61ssociation_type\x18\x06 \x01(\x0e\x32!.EMarketingMessageAssociationType: k_EMarketingMessageNoAssociation\x12\x15\n\rassociated_id\x18\x07 \x01(\r\x12\x17\n\x0f\x61ssociated_name\x18\x08 \x01(\t\x12\x12\n\nstart_date\x18\t \x01(\r\x12\x10\n\x08\x65nd_date\x18\n \x01(\r\x12\x15\n\rcountry_allow\x18\x0b \x01(\t\x12\x14\n\x0c\x63ountry_deny\x18\x0c \x01(\t\x12)\n!ownership_restrictions_overridden\x18\r \x01(\x08\x12\x16\n\x0emust_own_appid\x18\x0e \x01(\r\x12\x1a\n\x12must_not_own_appid\x18\x0f \x01(\r\x12\x1a\n\x12must_own_packageid\x18\x10 \x01(\r\x12\x1e\n\x16must_not_own_packageid\x18\x11 \x01(\r\x12 \n\x18must_have_launched_appid\x18\x12 \x01(\r\x12\x1f\n\x17\x61\x64\x64itional_restrictions\x18\x13 \x01(\t\x12\x15\n\rtemplate_type\x18\x14 \x01(\t\x12\x15\n\rtemplate_vars\x18\x15 \x01(\t\x12\r\n\x05\x66lags\x18\x16 \x01(\r\x12\x14\n\x0c\x63reator_name\x18\x17 \x01(\t\x12\x1a\n\x12template_vars_json\x18\x18 \x01(\t\x12$\n\x1c\x61\x64\x64itional_restrictions_json\x18\x19 \x01(\t\"\x82\x01\n6CMarketingMessages_GetActiveMarketingMessages_Response\x12)\n\x08messages\x18\x01 \x03(\x0b\x32\x17.CMarketingMessageProto\x12\x1d\n\x15time_next_message_age\x18\x02 \x01(\r\"f\n3CMarketingMessages_GetPastMarketingMessages_Request\x12\x17\n\x0fstart_past_days\x18\x01 \x01(\r\x12\x16\n\x0eupto_past_days\x18\x02 \x01(\r\"a\n4CMarketingMessages_GetPastMarketingMessages_Response\x12)\n\x08messages\x18\x01 \x03(\x0b\x32\x17.CMarketingMessageProto\"\x93\x02\n6CMarketingMessages_GetMarketingMessagesForUser_Request\x12\x1d\n\x15include_seen_messages\x18\x01 \x01(\x08\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x11\n\telanguage\x18\x03 \x01(\x05\x12\x18\n\x10operating_system\x18\x04 \x01(\x05\x12\x1e\n\x16\x63lient_package_version\x18\x05 \x01(\x05\x12$\n\x07\x63ontext\x18\x06 \x01(\x0b\x32\x13.StoreBrowseContext\x12\x31\n\x0c\x64\x61ta_request\x18\x07 \x01(\x0b\x32\x1b.StoreBrowseItemDataRequest\"\x93\x02\n\x18\x43\x44isplayMarketingMessage\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\r\n\x05title\x18\x02 \x01(\t\x12@\n\x04type\x18\x03 \x01(\x0e\x32\x16.EMarketingMessageType:\x1ak_EMarketingMessageInvalid\x12(\n\x12\x61ssociated_item_id\x18\x04 \x01(\x0b\x32\x0c.StoreItemID\x12#\n\x0f\x61ssociated_item\x18\x05 \x01(\x0b\x32\n.StoreItem\x12\x17\n\x0f\x61ssociated_name\x18\x06 \x01(\t\x12\x15\n\rtemplate_type\x18\n \x01(\t\x12\x1a\n\x12template_vars_json\x18\x0b \x01(\t\"\xfa\x01\n7CMarketingMessages_GetMarketingMessagesForUser_Response\x12\x62\n\x08messages\x18\x01 \x03(\x0b\x32P.CMarketingMessages_GetMarketingMessagesForUser_Response.MarketingMessageForUser\x1a[\n\x17MarketingMessageForUser\x12\x14\n\x0c\x61lready_seen\x18\x01 \x01(\x08\x12*\n\x07message\x18\x02 \x01(\x0b\x32\x19.CDisplayMarketingMessage\"\xa4\x01\n?CMarketingMessages_DoesUserHavePendingMarketingMessages_Request\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x11\n\telanguage\x18\x03 \x01(\x05\x12\x18\n\x10operating_system\x18\x04 \x01(\x05\x12\x1e\n\x16\x63lient_package_version\x18\x05 \x01(\x05\"\x7f\n@CMarketingMessages_DoesUserHavePendingMarketingMessages_Response\x12\x1c\n\x14has_pending_messages\x18\x01 \x01(\x08\x12\x1d\n\x15pending_message_count\x18\x02 \x01(\x05\"\x9d\x01\n5CMarketingMessages_GetDisplayMarketingMessage_Request\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12$\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x13.StoreBrowseContext\x12\x31\n\x0c\x64\x61ta_request\x18\x03 \x01(\x0b\x32\x1b.StoreBrowseItemDataRequest\"d\n6CMarketingMessages_GetDisplayMarketingMessage_Response\x12*\n\x07message\x18\x01 \x01(\x0b\x32\x19.CDisplayMarketingMessage\"\xb4\x01\n/CMarketingMessages_MarkMessageSeen_Notification\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\x18\n\rdisplay_index\x18\x02 \x01(\r:\x01\x30\x12Z\n\rtemplate_type\x18\x03 \x01(\x0e\x32\x1e.EMarketingMessageTemplateType:#k_EMarketingMessageTemplate_Unknown\"\x9a\x02\n2CMarketingMessages_MarkMessageClicked_Notification\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\x18\n\rdisplay_index\x18\x02 \x01(\r:\x01\x30\x12Z\n\rtemplate_type\x18\x03 \x01(\x0e\x32\x1e.EMarketingMessageTemplateType:#k_EMarketingMessageTemplate_Unknown\x12\x61\n\x0e\x63lick_location\x18\x04 \x01(\x0e\x32\x1f.EMarketingMessageClickLocation:(k_EMarketingMessageClickLocation_Unknown\"=\n.CMarketingMessages_GetMarketingMessage_Request\x12\x0b\n\x03gid\x18\x01 \x01(\x06\"[\n/CMarketingMessages_GetMarketingMessage_Response\x12(\n\x07message\x18\x01 \x01(\x0b\x32\x17.CMarketingMessageProto\"p\n1CMarketingMessages_CreateMarketingMessage_Request\x12(\n\x07message\x18\x01 \x01(\x0b\x32\x17.CMarketingMessageProto\x12\x11\n\tfrom_json\x18\x02 \x01(\x08\"A\n2CMarketingMessages_CreateMarketingMessage_Response\x12\x0b\n\x03gid\x18\x01 \x01(\x06\"}\n1CMarketingMessages_UpdateMarketingMessage_Request\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12(\n\x07message\x18\x02 \x01(\x0b\x32\x17.CMarketingMessageProto\x12\x11\n\tfrom_json\x18\x03 \x01(\x08\"4\n2CMarketingMessages_UpdateMarketingMessage_Response\"@\n1CMarketingMessages_DeleteMarketingMessage_Request\x12\x0b\n\x03gid\x18\x01 \x01(\x06\"4\n2CMarketingMessages_DeleteMarketingMessage_Response\"\xfe\x01\n0CMarketingMessages_FindMarketingMessages_Request\x12S\n\x0blookup_type\x18\x01 \x01(\x0e\x32\x1c.EMarketingMessageLookupType: k_EMarketingMessageLookupInvalid\x12\x0b\n\x03gid\x18\x02 \x01(\x06\x12H\n\x0cmessage_type\x18\x03 \x01(\x0e\x32\x16.EMarketingMessageType:\x1ak_EMarketingMessageInvalid\x12\x0f\n\x07gidlist\x18\x04 \x03(\x06\x12\r\n\x05title\x18\x05 \x01(\t\"^\n1CMarketingMessages_FindMarketingMessages_Response\x12)\n\x08messages\x18\x01 \x03(\x0b\x32\x17.CMarketingMessageProto\"H\n9CMarketingMessages_GetMarketingMessageViewerStats_Request\x12\x0b\n\x03gid\x18\x01 \x01(\x06\"\xbb\x01\n\x1c\x43MarketingMessageHourlyStats\x12\x14\n\x0crt_time_hour\x18\x01 \x01(\r\x12\x12\n\nseen_count\x18\x02 \x01(\r\x12Z\n\rtemplate_type\x18\x03 \x01(\x0e\x32\x1e.EMarketingMessageTemplateType:#k_EMarketingMessageTemplate_Unknown\x12\x15\n\rdisplay_index\x18\x04 \x01(\r\"j\n:CMarketingMessages_GetMarketingMessageViewerStats_Response\x12,\n\x05stats\x18\x01 \x03(\x0b\x32\x1d.CMarketingMessageHourlyStats\"m\n?CMarketingMessages_GetMarketingMessagesViewerRangeStats_Request\x12\x15\n\rrt_start_time\x18\x01 \x01(\r\x12\x13\n\x0brt_end_time\x18\x02 \x01(\r\"\xa8\x02\n#CMarketingMessageClickedHourlyStats\x12\x14\n\x0crt_time_hour\x18\x01 \x01(\r\x12\x15\n\rclicked_count\x18\x02 \x01(\r\x12\x15\n\rdisplay_index\x18\x03 \x01(\r\x12Z\n\rtemplate_type\x18\x04 \x01(\x0e\x32\x1e.EMarketingMessageTemplateType:#k_EMarketingMessageTemplate_Unknown\x12\x61\n\x0e\x63lick_location\x18\x05 \x01(\x0e\x32\x1f.EMarketingMessageClickLocation:(k_EMarketingMessageClickLocation_Unknown\"\xad\x01\n@CMarketingMessages_GetMarketingMessagesViewerRangeStats_Response\x12,\n\x05stats\x18\x01 \x03(\x0b\x32\x1d.CMarketingMessageHourlyStats\x12;\n\rclicked_stats\x18\x02 \x03(\x0b\x32$.CMarketingMessageClickedHourlyStats\"I\n:CMarketingMessages_GetMarketingMessageClickedStats_Request\x12\x0b\n\x03gid\x18\x01 \x01(\x06\"r\n;CMarketingMessages_GetMarketingMessageClickedStats_Response\x12\x33\n\x05stats\x18\x01 \x03(\x0b\x32$.CMarketingMessageClickedHourlyStats\"P\n;CMarketingMessages_GetPartnerReadyToPublishMessages_Request\x12\x11\n\tpartnerid\x18\x01 \x01(\r\"k\n<CMarketingMessages_GetPartnerReadyToPublishMessages_Response\x12+\n\x08messages\x18\x01 \x03(\x0b\x32\x19.CDisplayMarketingMessage\"R\n0CMarketingMessages_PartnerPublishMessage_Request\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\x11\n\tpartnerid\x18\x02 \x01(\r\"3\n1CMarketingMessages_PartnerPublishMessage_Response\"U\n3CMarketingMessages_GetPartnerMessagePreview_Request\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\x11\n\tpartnerid\x18\x02 \x01(\r\"`\n4CMarketingMessages_GetPartnerMessagePreview_Response\x12(\n\x07message\x18\x01 \x01(\x0b\x32\x17.CMarketingMessageProto\"M\n8CMarketingMessage_GetMarketingMessagesForPartner_Request\x12\x11\n\tpartnerid\x18\x01 \x01(\r\"f\n9CMarketingMessage_GetMarketingMessagesForPartner_Response\x12)\n\x08messages\x18\x01 \x03(\x0b\x32\x17.CMarketingMessageProto\"G\n5CMarketingMessage_GetMarketingMessagesForApps_Request\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\r\"c\n6CMarketingMessage_GetMarketingMessagesForApps_Response\x12)\n\x08messages\x18\x01 \x03(\x0b\x32\x17.CMarketingMessageProto*\xde\x04\n\x15\x45MarketingMessageType\x12\x1e\n\x1ak_EMarketingMessageInvalid\x10\x00\x12#\n\x1fk_EMarketingMessageNowAvailable\x10\x01\x12\"\n\x1ek_EMarketingMessageWeekendDeal\x10\x02\x12\"\n\x1ek_EMarketingMessagePrePurchase\x10\x03\x12\x1e\n\x1ak_EMarketingMessagePlayNow\x10\x04\x12!\n\x1dk_EMarketingMessagePreloadNow\x10\x05\x12\x1e\n\x1ak_EMarketingMessageGeneral\x10\x06\x12\x1f\n\x1bk_EMarketingMessageDemoQuit\x10\x07\x12\x1e\n\x1ak_EMarketingMessageGifting\x10\x08\x12 \n\x1ck_EMarketingMessageEJsKorner\x10\t\x12\x1d\n\x19k_EMarketingMessageUpdate\x10\n\x12\"\n\x1ek_EMarketingMessageMidweekDeal\x10\x0b\x12 \n\x1ck_EMarketingMessageDailyDeal\x10\x0c\x12\x1d\n\x19k_EMarketingMessageNewDLC\x10\r\x12\"\n\x1ek_EMarketingMessageFreeWeekend\x10\x0e\x12 \n\x1ck_EMarketingMessageSalePages\x10\x0f\x12(\n$k_EMarketingMessagePlaytestAvailable\x10\x10*\x99\x01\n\x1b\x45MarketingMessageVisibility\x12\"\n\x1ek_EMarketingMessageVisibleBeta\x10\x01\x12$\n k_EMarketingMessageVisiblePublic\x10\x02\x12\x30\n,k_EMarketingMessageVisibleApprovedForPublish\x10\x03*\x9f\x02\n EMarketingMessageAssociationType\x12$\n k_EMarketingMessageNoAssociation\x10\x00\x12%\n!k_EMarketingMessageAppAssociation\x10\x01\x12.\n*k_EMarketingMessageSubscriptionAssociation\x10\x02\x12+\n\'k_EMarketingMessagePublisherAssociation\x10\x03\x12\'\n#k_EMarketingMessageGenreAssociation\x10\x04\x12(\n$k_EMarketingMessageBundleAssociation\x10\x05*\x97\x03\n\x1d\x45MarketingMessageTemplateType\x12\'\n#k_EMarketingMessageTemplate_Unknown\x10\x00\x12%\n!k_EMarketingMessageTemplate_Image\x10\x01\x12(\n$k_EMarketingMessageTemplate_Animated\x10\x02\x12.\n*k_EMarketingMessageTemplate_Featured_Video\x10\x03\x12,\n(k_EMarketingMessageTemplate_DLC_Override\x10\x04\x12&\n\"k_EMarketingMessageTemplate_Replay\x10\x05\x12%\n!k_EMarketingMessageTemplate_Event\x10\x06\x12*\n&k_EMarketingMessageTemplate_AutoRender\x10\x07\x12#\n\x1fk_EMarketingMessageTemplate_MAX\x10\x08*\xee\x02\n\x1e\x45MarketingMessageClickLocation\x12,\n(k_EMarketingMessageClickLocation_Unknown\x10\x00\x12*\n&k_EMarketingMessageClickLocation_Image\x10\x01\x12+\n\'k_EMarketingMessageClickLocation_Button\x10\x02\x12/\n+k_EMarketingMessageClickLocation_DlcCapsule\x10\x03\x12/\n+k_EMarketingMessageClickLocation_HeaderArea\x10\x04\x12\x30\n,k_EMarketingMessageClickLocation_GameCapsule\x10\x05\x12\x31\n-k_EMarketingMessageClickLocation_PartnerEvent\x10\x06*\xe2\x01\n\x1b\x45MarketingMessageLookupType\x12$\n k_EMarketingMessageLookupInvalid\x10\x00\x12\"\n\x1ek_EMarketingMessageLookupByGID\x10\x01\x12#\n\x1fk_EMarketingMessageLookupActive\x10\x02\x12,\n(k_EMarketingMessageLookupByTitleWithType\x10\x03\x12&\n\"k_EMarketingMessageLookupByGIDList\x10\x04\x32\x9a\x18\n\x11MarketingMessages\x12\x8d\x01\n\x1aGetActiveMarketingMessages\x12\x36.CMarketingMessages_GetActiveMarketingMessages_Request\x1a\x37.CMarketingMessages_GetActiveMarketingMessages_Response\x12\x87\x01\n\x18GetPastMarketingMessages\x12\x34.CMarketingMessages_GetPastMarketingMessages_Request\x1a\x35.CMarketingMessages_GetPastMarketingMessages_Response\x12\x90\x01\n\x1bGetMarketingMessagesForUser\x12\x37.CMarketingMessages_GetMarketingMessagesForUser_Request\x1a\x38.CMarketingMessages_GetMarketingMessagesForUser_Response\x12\xab\x01\n$DoesUserHavePendingMarketingMessages\x12@.CMarketingMessages_DoesUserHavePendingMarketingMessages_Request\x1a\x41.CMarketingMessages_DoesUserHavePendingMarketingMessages_Response\x12\x8d\x01\n\x1aGetDisplayMarketingMessage\x12\x36.CMarketingMessages_GetDisplayMarketingMessage_Request\x1a\x37.CMarketingMessages_GetDisplayMarketingMessage_Response\x12\x94\x01\n!GetDisplayMarketingMessageForUser\x12\x36.CMarketingMessages_GetDisplayMarketingMessage_Request\x1a\x37.CMarketingMessages_GetDisplayMarketingMessage_Response\x12\x92\x01\n\x1fGetDisplayMarketingMessageAdmin\x12\x36.CMarketingMessages_GetDisplayMarketingMessage_Request\x1a\x37.CMarketingMessages_GetDisplayMarketingMessage_Response\x12P\n\x0fMarkMessageSeen\x12\x30.CMarketingMessages_MarkMessageSeen_Notification\x1a\x0b.NoResponse\x12V\n\x12MarkMessageClicked\x12\x33.CMarketingMessages_MarkMessageClicked_Notification\x1a\x0b.NoResponse\x12x\n\x13GetMarketingMessage\x12/.CMarketingMessages_GetMarketingMessage_Request\x1a\x30.CMarketingMessages_GetMarketingMessage_Response\x12\x81\x01\n\x16\x43reateMarketingMessage\x12\x32.CMarketingMessages_CreateMarketingMessage_Request\x1a\x33.CMarketingMessages_CreateMarketingMessage_Response\x12\x81\x01\n\x16UpdateMarketingMessage\x12\x32.CMarketingMessages_UpdateMarketingMessage_Request\x1a\x33.CMarketingMessages_UpdateMarketingMessage_Response\x12\x81\x01\n\x16\x44\x65leteMarketingMessage\x12\x32.CMarketingMessages_DeleteMarketingMessage_Request\x1a\x33.CMarketingMessages_DeleteMarketingMessage_Response\x12~\n\x15\x46indMarketingMessages\x12\x31.CMarketingMessages_FindMarketingMessages_Request\x1a\x32.CMarketingMessages_FindMarketingMessages_Response\x12\x99\x01\n\x1eGetMarketingMessageViewerStats\x12:.CMarketingMessages_GetMarketingMessageViewerStats_Request\x1a;.CMarketingMessages_GetMarketingMessageViewerStats_Response\x12\xab\x01\n$GetMarketingMessagesViewerRangeStats\x12@.CMarketingMessages_GetMarketingMessagesViewerRangeStats_Request\x1a\x41.CMarketingMessages_GetMarketingMessagesViewerRangeStats_Response\x12\x9c\x01\n\x1fGetMarketingMessageClickedStats\x12;.CMarketingMessages_GetMarketingMessageClickedStats_Request\x1a<.CMarketingMessages_GetMarketingMessageClickedStats_Response\x12\x9f\x01\n GetPartnerReadyToPublishMessages\x12<.CMarketingMessages_GetPartnerReadyToPublishMessages_Request\x1a=.CMarketingMessages_GetPartnerReadyToPublishMessages_Response\x12~\n\x15PublishPartnerMessage\x12\x31.CMarketingMessages_PartnerPublishMessage_Request\x1a\x32.CMarketingMessages_PartnerPublishMessage_Response\x12\x87\x01\n\x18GetPartnerMessagePreview\x12\x34.CMarketingMessages_GetPartnerMessagePreview_Request\x1a\x35.CMarketingMessages_GetPartnerMessagePreview_Response\x12\x97\x01\n\x1eGetMarketingMessagesForPartner\x12\x39.CMarketingMessage_GetMarketingMessagesForPartner_Request\x1a:.CMarketingMessage_GetMarketingMessagesForPartner_Response\x12\x8e\x01\n\x1bGetMarketingMessagesForApps\x12\x36.CMarketingMessage_GetMarketingMessagesForApps_Request\x1a\x37.CMarketingMessage_GetMarketingMessagesForApps_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_marketingmessages_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _EMARKETINGMESSAGETYPE._serialized_start=6232
  _EMARKETINGMESSAGETYPE._serialized_end=6838
  _EMARKETINGMESSAGEVISIBILITY._serialized_start=6841
  _EMARKETINGMESSAGEVISIBILITY._serialized_end=6994
  _EMARKETINGMESSAGEASSOCIATIONTYPE._serialized_start=6997
  _EMARKETINGMESSAGEASSOCIATIONTYPE._serialized_end=7284
  _EMARKETINGMESSAGETEMPLATETYPE._serialized_start=7287
  _EMARKETINGMESSAGETEMPLATETYPE._serialized_end=7694
  _EMARKETINGMESSAGECLICKLOCATION._serialized_start=7697
  _EMARKETINGMESSAGECLICKLOCATION._serialized_end=8063
  _EMARKETINGMESSAGELOOKUPTYPE._serialized_start=8066
  _EMARKETINGMESSAGELOOKUPTYPE._serialized_end=8292
  _CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_REQUEST._serialized_start=134
  _CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_REQUEST._serialized_end=230
  _CMARKETINGMESSAGEPROTO._serialized_start=233
  _CMARKETINGMESSAGEPROTO._serialized_end=1048
  _CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_RESPONSE._serialized_start=1051
  _CMARKETINGMESSAGES_GETACTIVEMARKETINGMESSAGES_RESPONSE._serialized_end=1181
  _CMARKETINGMESSAGES_GETPASTMARKETINGMESSAGES_REQUEST._serialized_start=1183
  _CMARKETINGMESSAGES_GETPASTMARKETINGMESSAGES_REQUEST._serialized_end=1285
  _CMARKETINGMESSAGES_GETPASTMARKETINGMESSAGES_RESPONSE._serialized_start=1287
  _CMARKETINGMESSAGES_GETPASTMARKETINGMESSAGES_RESPONSE._serialized_end=1384
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_REQUEST._serialized_start=1387
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_REQUEST._serialized_end=1662
  _CDISPLAYMARKETINGMESSAGE._serialized_start=1665
  _CDISPLAYMARKETINGMESSAGE._serialized_end=1940
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE._serialized_start=1943
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE._serialized_end=2193
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE_MARKETINGMESSAGEFORUSER._serialized_start=2102
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGESFORUSER_RESPONSE_MARKETINGMESSAGEFORUSER._serialized_end=2193
  _CMARKETINGMESSAGES_DOESUSERHAVEPENDINGMARKETINGMESSAGES_REQUEST._serialized_start=2196
  _CMARKETINGMESSAGES_DOESUSERHAVEPENDINGMARKETINGMESSAGES_REQUEST._serialized_end=2360
  _CMARKETINGMESSAGES_DOESUSERHAVEPENDINGMARKETINGMESSAGES_RESPONSE._serialized_start=2362
  _CMARKETINGMESSAGES_DOESUSERHAVEPENDINGMARKETINGMESSAGES_RESPONSE._serialized_end=2489
  _CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_REQUEST._serialized_start=2492
  _CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_REQUEST._serialized_end=2649
  _CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_RESPONSE._serialized_start=2651
  _CMARKETINGMESSAGES_GETDISPLAYMARKETINGMESSAGE_RESPONSE._serialized_end=2751
  _CMARKETINGMESSAGES_MARKMESSAGESEEN_NOTIFICATION._serialized_start=2754
  _CMARKETINGMESSAGES_MARKMESSAGESEEN_NOTIFICATION._serialized_end=2934
  _CMARKETINGMESSAGES_MARKMESSAGECLICKED_NOTIFICATION._serialized_start=2937
  _CMARKETINGMESSAGES_MARKMESSAGECLICKED_NOTIFICATION._serialized_end=3219
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGE_REQUEST._serialized_start=3221
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGE_REQUEST._serialized_end=3282
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGE_RESPONSE._serialized_start=3284
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGE_RESPONSE._serialized_end=3375
  _CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_REQUEST._serialized_start=3377
  _CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_REQUEST._serialized_end=3489
  _CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_RESPONSE._serialized_start=3491
  _CMARKETINGMESSAGES_CREATEMARKETINGMESSAGE_RESPONSE._serialized_end=3556
  _CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_REQUEST._serialized_start=3558
  _CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_REQUEST._serialized_end=3683
  _CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_RESPONSE._serialized_start=3685
  _CMARKETINGMESSAGES_UPDATEMARKETINGMESSAGE_RESPONSE._serialized_end=3737
  _CMARKETINGMESSAGES_DELETEMARKETINGMESSAGE_REQUEST._serialized_start=3739
  _CMARKETINGMESSAGES_DELETEMARKETINGMESSAGE_REQUEST._serialized_end=3803
  _CMARKETINGMESSAGES_DELETEMARKETINGMESSAGE_RESPONSE._serialized_start=3805
  _CMARKETINGMESSAGES_DELETEMARKETINGMESSAGE_RESPONSE._serialized_end=3857
  _CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_REQUEST._serialized_start=3860
  _CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_REQUEST._serialized_end=4114
  _CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_RESPONSE._serialized_start=4116
  _CMARKETINGMESSAGES_FINDMARKETINGMESSAGES_RESPONSE._serialized_end=4210
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGEVIEWERSTATS_REQUEST._serialized_start=4212
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGEVIEWERSTATS_REQUEST._serialized_end=4284
  _CMARKETINGMESSAGEHOURLYSTATS._serialized_start=4287
  _CMARKETINGMESSAGEHOURLYSTATS._serialized_end=4474
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGEVIEWERSTATS_RESPONSE._serialized_start=4476
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGEVIEWERSTATS_RESPONSE._serialized_end=4582
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGESVIEWERRANGESTATS_REQUEST._serialized_start=4584
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGESVIEWERRANGESTATS_REQUEST._serialized_end=4693
  _CMARKETINGMESSAGECLICKEDHOURLYSTATS._serialized_start=4696
  _CMARKETINGMESSAGECLICKEDHOURLYSTATS._serialized_end=4992
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGESVIEWERRANGESTATS_RESPONSE._serialized_start=4995
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGESVIEWERRANGESTATS_RESPONSE._serialized_end=5168
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGECLICKEDSTATS_REQUEST._serialized_start=5170
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGECLICKEDSTATS_REQUEST._serialized_end=5243
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGECLICKEDSTATS_RESPONSE._serialized_start=5245
  _CMARKETINGMESSAGES_GETMARKETINGMESSAGECLICKEDSTATS_RESPONSE._serialized_end=5359
  _CMARKETINGMESSAGES_GETPARTNERREADYTOPUBLISHMESSAGES_REQUEST._serialized_start=5361
  _CMARKETINGMESSAGES_GETPARTNERREADYTOPUBLISHMESSAGES_REQUEST._serialized_end=5441
  _CMARKETINGMESSAGES_GETPARTNERREADYTOPUBLISHMESSAGES_RESPONSE._serialized_start=5443
  _CMARKETINGMESSAGES_GETPARTNERREADYTOPUBLISHMESSAGES_RESPONSE._serialized_end=5550
  _CMARKETINGMESSAGES_PARTNERPUBLISHMESSAGE_REQUEST._serialized_start=5552
  _CMARKETINGMESSAGES_PARTNERPUBLISHMESSAGE_REQUEST._serialized_end=5634
  _CMARKETINGMESSAGES_PARTNERPUBLISHMESSAGE_RESPONSE._serialized_start=5636
  _CMARKETINGMESSAGES_PARTNERPUBLISHMESSAGE_RESPONSE._serialized_end=5687
  _CMARKETINGMESSAGES_GETPARTNERMESSAGEPREVIEW_REQUEST._serialized_start=5689
  _CMARKETINGMESSAGES_GETPARTNERMESSAGEPREVIEW_REQUEST._serialized_end=5774
  _CMARKETINGMESSAGES_GETPARTNERMESSAGEPREVIEW_RESPONSE._serialized_start=5776
  _CMARKETINGMESSAGES_GETPARTNERMESSAGEPREVIEW_RESPONSE._serialized_end=5872
  _CMARKETINGMESSAGE_GETMARKETINGMESSAGESFORPARTNER_REQUEST._serialized_start=5874
  _CMARKETINGMESSAGE_GETMARKETINGMESSAGESFORPARTNER_REQUEST._serialized_end=5951
  _CMARKETINGMESSAGE_GETMARKETINGMESSAGESFORPARTNER_RESPONSE._serialized_start=5953
  _CMARKETINGMESSAGE_GETMARKETINGMESSAGESFORPARTNER_RESPONSE._serialized_end=6055
  _CMARKETINGMESSAGE_GETMARKETINGMESSAGESFORAPPS_REQUEST._serialized_start=6057
  _CMARKETINGMESSAGE_GETMARKETINGMESSAGESFORAPPS_REQUEST._serialized_end=6128
  _CMARKETINGMESSAGE_GETMARKETINGMESSAGESFORAPPS_RESPONSE._serialized_start=6130
  _CMARKETINGMESSAGE_GETMARKETINGMESSAGESFORAPPS_RESPONSE._serialized_end=6229
  _MARKETINGMESSAGES._serialized_start=8295
  _MARKETINGMESSAGES._serialized_end=11393
_builder.BuildServices(DESCRIPTOR, 'steammessages_marketingmessages_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"steammessages_clientserver_2.proto\x1a\x18steammessages_base.proto\"w\n\x1c\x43MsgClientUpdateUserGameInfo\x12\x14\n\x0csteamid_idgs\x18\x01 \x01(\x06\x12\x0e\n\x06gameid\x18\x02 \x01(\x06\x12\x0f\n\x07game_ip\x18\x03 \x01(\r\x12\x11\n\tgame_port\x18\x04 \x01(\r\x12\r\n\x05token\x18\x05 \x01(\x0c\"S\n\x1c\x43MsgClientRichPresenceUpload\x12\x18\n\x10rich_presence_kv\x18\x01 \x01(\x0c\x12\x19\n\x11steamid_broadcast\x18\x02 \x03(\x06\"8\n\x1d\x43MsgClientRichPresenceRequest\x12\x17\n\x0fsteamid_request\x18\x01 \x03(\x06\"\xf6\x01\n\x1a\x43MsgClientRichPresenceInfo\x12?\n\rrich_presence\x18\x01 \x03(\x0b\x32(.CMsgClientRichPresenceInfo.RichPresence\x1a \n\x02KV\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1au\n\x0cRichPresence\x12\x14\n\x0csteamid_user\x18\x01 \x01(\x06\x12\x18\n\x10rich_presence_kv\x18\x02 \x01(\x0c\x12\x35\n\rrich_presense\x18\x03 \x03(\x0b\x32\x1e.CMsgClientRichPresenceInfo.KV\".\n\x1c\x43MsgClientCheckFileSignature\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\"\xf7\x01\n$CMsgClientCheckFileSignatureResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x0b\n\x03pid\x18\x02 \x01(\r\x12\x0f\n\x07\x65result\x18\x03 \x01(\r\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x18\n\x10\x65signatureresult\x18\x05 \x01(\r\x12\x10\n\x08sha_file\x18\x06 \x01(\x0c\x12\x17\n\x0fsignatureheader\x18\x07 \x01(\x0c\x12\x10\n\x08\x66ilesize\x18\x08 \x01(\r\x12\x14\n\x0cgetlasterror\x18\t \x01(\r\x12\"\n\x1a\x65valvesignaturecheckdetail\x18\n \x01(\r\"$\n\x15\x43MsgClientRegisterKey\x12\x0b\n\x03key\x18\x01 \x01(\t\"p\n\x1a\x43MsgClientPurchaseResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x1f\n\x17purchase_result_details\x18\x02 \x01(\x05\x12\x1d\n\x15purchase_receipt_info\x18\x03 \x01(\x0c\"\xc5\x01\n\x1c\x43MsgClientActivateOEMLicense\x12\x19\n\x11\x62ios_manufacturer\x18\x01 \x01(\t\x12\x19\n\x11\x62ios_serialnumber\x18\x02 \x01(\t\x12\x14\n\x0clicense_file\x18\x03 \x01(\x0c\x12\x1e\n\x16mainboard_manufacturer\x18\x04 \x01(\t\x12\x19\n\x11mainboard_product\x18\x05 \x01(\t\x12\x1e\n\x16mainboard_serialnumber\x18\x06 \x01(\t\"9\n\x1c\x43MsgClientRegisterOEMMachine\x12\x19\n\x11oem_register_file\x18\x01 \x01(\x0c\"7\n$CMsgClientRegisterOEMMachineResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"K\n\x1f\x43MsgClientPurchaseWithMachineID\x12\x12\n\npackage_id\x18\x01 \x01(\r\x12\x14\n\x0cmachine_info\x18\x02 \x01(\x0c\"g\n CMsgTrading_InitiateTradeRequest\x12\x18\n\x10trade_request_id\x18\x01 \x01(\r\x12\x15\n\rother_steamid\x18\x02 \x01(\x04\x12\x12\n\nother_name\x18\x03 \x01(\t\"\xd2\x02\n!CMsgTrading_InitiateTradeResponse\x12\x10\n\x08response\x18\x01 \x01(\r\x12\x18\n\x10trade_request_id\x18\x02 \x01(\r\x12\x15\n\rother_steamid\x18\x03 \x01(\x04\x12 \n\x18steamguard_required_days\x18\x04 \x01(\r\x12 \n\x18new_device_cooldown_days\x18\x05 \x01(\r\x12-\n%default_password_reset_probation_days\x18\x06 \x01(\r\x12%\n\x1dpassword_reset_probation_days\x18\x07 \x01(\r\x12+\n#default_email_change_probation_days\x18\x08 \x01(\r\x12#\n\x1b\x65mail_change_probation_days\x18\t \x01(\r\"7\n\x1e\x43MsgTrading_CancelTradeRequest\x12\x15\n\rother_steamid\x18\x01 \x01(\x04\"1\n\x18\x43MsgTrading_StartSession\x12\x15\n\rother_steamid\x18\x01 \x01(\x04\"C\n\x1f\x43MsgClientGetDepotDecryptionKey\x12\x10\n\x08\x64\x65pot_id\x18\x01 \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\"m\n\'CMsgClientGetDepotDecryptionKeyResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x10\n\x08\x64\x65pot_id\x18\x02 \x01(\r\x12\x1c\n\x14\x64\x65pot_encryption_key\x18\x03 \x01(\x0c\"X\n\x1e\x43MsgClientCheckAppBetaPassword\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x14\n\x0c\x62\x65tapassword\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\x05\"\xda\x01\n&CMsgClientCheckAppBetaPasswordResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12K\n\rbetapasswords\x18\x04 \x03(\x0b\x32\x34.CMsgClientCheckAppBetaPasswordResponse.BetaPassword\x1aO\n\x0c\x42\x65taPassword\x12\x10\n\x08\x62\x65taname\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x65tapassword\x18\x02 \x01(\t\x12\x17\n\x0f\x62\x65tadescription\x18\x03 \x01(\t\"\x99\x01\n\x1b\x43MsgClientUGSGetGlobalStats\x12\x0e\n\x06gameid\x18\x01 \x01(\x04\x12\x1e\n\x16history_days_requested\x18\x02 \x01(\r\x12\x1b\n\x13time_last_requested\x18\x03 \x01(\x07\x12\x18\n\x10\x66irst_day_cached\x18\x04 \x01(\r\x12\x13\n\x0b\x64\x61ys_cached\x18\x05 \x01(\r\"\x95\x02\n#CMsgClientUGSGetGlobalStatsResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x11\n\ttimestamp\x18\x02 \x01(\x07\x12\x13\n\x0b\x64\x61y_current\x18\x03 \x01(\x05\x12\x36\n\x04\x64\x61ys\x18\x04 \x03(\x0b\x32(.CMsgClientUGSGetGlobalStatsResponse.Day\x1az\n\x03\x44\x61y\x12\x0e\n\x06\x64\x61y_id\x18\x01 \x01(\r\x12<\n\x05stats\x18\x02 \x03(\x0b\x32-.CMsgClientUGSGetGlobalStatsResponse.Day.Stat\x1a%\n\x04Stat\x12\x0f\n\x07stat_id\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x03\"2\n\x19\x43MsgClientRedeemGuestPass\x12\x15\n\rguest_pass_id\x18\x01 \x01(\x06\"c\n!CMsgClientRedeemGuestPassResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x12\n\npackage_id\x18\x02 \x01(\r\x12\x16\n\x0emust_own_appid\x18\x03 \x01(\r\"8\n\x1f\x43MsgClientGetClanActivityCounts\x12\x15\n\rsteamid_clans\x18\x01 \x03(\x04\"=\n\'CMsgClientGetClanActivityCountsResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\"y\n\x19\x43MsgClientOGSReportString\x12\x13\n\x0b\x61\x63\x63umulated\x18\x01 \x01(\x08\x12\x11\n\tsessionid\x18\x02 \x01(\x04\x12\x10\n\x08severity\x18\x03 \x01(\x05\x12\x11\n\tformatter\x18\x04 \x01(\t\x12\x0f\n\x07varargs\x18\x05 \x01(\x0c\"P\n\x16\x43MsgClientOGSReportBug\x12\x11\n\tsessionid\x18\x01 \x01(\x04\x12\x0f\n\x07\x62ugtext\x18\x02 \x01(\t\x12\x12\n\nscreenshot\x18\x03 \x01(\x0c\"\x14\n\x12\x43MsgClientSentLogs\"\x92\x01\n\x0c\x43MsgGCClient\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07msgtype\x18\x02 \x01(\r\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\x0f\n\x07steamid\x18\x04 \x01(\x06\x12\x0e\n\x06gcname\x18\x05 \x01(\t\x12\n\n\x02ip\x18\x06 \x01(\r\x12\r\n\x05\x66lags\x18\x07 \x01(\r\"\x15\n\x05\x45\x46lag\x12\x0c\n\x08VALVE_DS\x10\x01\".\n\x1c\x43MsgClientRequestFreeLicense\x12\x0e\n\x06\x61ppids\x18\x02 \x03(\r\"n\n$CMsgClientRequestFreeLicenseResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x1a\n\x12granted_packageids\x18\x02 \x03(\r\x12\x16\n\x0egranted_appids\x18\x03 \x03(\r\"\xd3\x01\n#CMsgDRMDownloadRequestWithCrashData\x12\x16\n\x0e\x64ownload_flags\x18\x01 \x01(\r\x12\x1c\n\x14\x64ownload_types_known\x18\x02 \x01(\r\x12\x10\n\x08guid_drm\x18\x03 \x01(\x0c\x12\x12\n\nguid_split\x18\x04 \x01(\x0c\x12\x12\n\nguid_merge\x18\x05 \x01(\x0c\x12\x13\n\x0bmodule_name\x18\x06 \x01(\t\x12\x13\n\x0bmodule_path\x18\x07 \x01(\t\x12\x12\n\ncrash_data\x18\x08 \x01(\x0c\"\xdb\x01\n\x17\x43MsgDRMDownloadResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x1a\n\x12\x62lob_download_type\x18\x03 \x01(\r\x12\x12\n\nmerge_guid\x18\x04 \x01(\x0c\x12\x1c\n\x14\x64ownload_file_dfs_ip\x18\x05 \x01(\r\x12\x1e\n\x16\x64ownload_file_dfs_port\x18\x06 \x01(\r\x12\x19\n\x11\x64ownload_file_url\x18\x07 \x01(\t\x12\x13\n\x0bmodule_path\x18\x08 \x01(\t\"\xd7\x01\n\x12\x43MsgDRMFinalResult\x12\x12\n\x07\x65Result\x18\x01 \x01(\r:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x1a\n\x12\x62lob_download_type\x18\x03 \x01(\r\x12\x14\n\x0c\x65rror_detail\x18\x04 \x01(\r\x12\x12\n\nmerge_guid\x18\x05 \x01(\x0c\x12\x1c\n\x14\x64ownload_file_dfs_ip\x18\x06 \x01(\r\x12\x1e\n\x16\x64ownload_file_dfs_port\x18\x07 \x01(\r\x12\x19\n\x11\x64ownload_file_url\x18\x08 \x01(\t\"3\n\x1e\x43MsgClientDPCheckSpecialSurvey\x12\x11\n\tsurvey_id\x18\x01 \x01(\r\"\x96\x01\n&CMsgClientDPCheckSpecialSurveyResponse\x12\x12\n\x07\x65Result\x18\x01 \x01(\r:\x01\x32\x12\r\n\x05state\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\ncustom_url\x18\x04 \x01(\t\x12\x18\n\x10include_software\x18\x05 \x01(\x08\x12\r\n\x05token\x18\x06 \x01(\x0c\"H\n%CMsgClientDPSendSpecialSurveyResponse\x12\x11\n\tsurvey_id\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"O\n*CMsgClientDPSendSpecialSurveyResponseReply\x12\x12\n\x07\x65Result\x18\x01 \x01(\r:\x01\x32\x12\r\n\x05token\x18\x02 \x01(\x0c\"W\n\'CMsgClientRequestForgottenPasswordEmail\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12\x16\n\x0epassword_tried\x18\x02 \x01(\t\"_\n/CMsgClientRequestForgottenPasswordEmailResponse\x12\x0f\n\x07\x65Result\x18\x01 \x01(\r\x12\x1b\n\x13use_secret_question\x18\x02 \x01(\x08\"\xf6\x01\n\x1b\x43MsgClientItemAnnouncements\x12\x17\n\x0f\x63ount_new_items\x18\x01 \x01(\r\x12=\n\x0cunseen_items\x18\x02 \x03(\x0b\x32\'.CMsgClientItemAnnouncements.UnseenItem\x1a\x7f\n\nUnseenItem\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\ncontext_id\x18\x02 \x01(\x04\x12\x10\n\x08\x61sset_id\x18\x03 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x04\x12\x16\n\x0ertime32_gained\x18\x05 \x01(\x07\x12\x14\n\x0csource_appid\x18\x06 \x01(\r\"$\n\"CMsgClientRequestItemAnnouncements\"\x9e\x01\n\x1b\x43MsgClientUserNotifications\x12@\n\rnotifications\x18\x01 \x03(\x0b\x32).CMsgClientUserNotifications.Notification\x1a=\n\x0cNotification\x12\x1e\n\x16user_notification_type\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"\x88\x01\n\x1e\x43MsgClientCommentNotifications\x12\x1a\n\x12\x63ount_new_comments\x18\x01 \x01(\r\x12 \n\x18\x63ount_new_comments_owner\x18\x02 \x01(\r\x12(\n count_new_comments_subscriptions\x18\x03 \x01(\r\"\'\n%CMsgClientRequestCommentNotifications\"g\n$CMsgClientOfflineMessageNotification\x12\x18\n\x10offline_messages\x18\x01 \x01(\r\x12%\n\x1d\x66riends_with_offline_messages\x18\x02 \x03(\r\"&\n$CMsgClientRequestOfflineMessageCount\"8\n%CMsgClientChatGetFriendMessageHistory\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xf9\x01\n-CMsgClientChatGetFriendMessageHistoryResponse\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0f\n\x07success\x18\x02 \x01(\r\x12N\n\x08messages\x18\x03 \x03(\x0b\x32<.CMsgClientChatGetFriendMessageHistoryResponse.FriendMessage\x1aV\n\rFriendMessage\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06unread\x18\x04 \x01(\x08\"9\n7CMsgClientChatGetFriendMessageHistoryForOfflineMessages\"7\n!CMsgClientFSGetFriendsSteamLevels\x12\x12\n\naccountids\x18\x01 \x03(\r\"\x9b\x01\n)CMsgClientFSGetFriendsSteamLevelsResponse\x12\x42\n\x07\x66riends\x18\x01 \x03(\x0b\x32\x31.CMsgClientFSGetFriendsSteamLevelsResponse.Friend\x1a*\n\x06\x46riend\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\r\n\x05level\x18\x02 \x01(\r\"\xca\x01\n\x17\x43MsgClientEmailAddrInfo\x12\x15\n\remail_address\x18\x01 \x01(\t\x12\x1a\n\x12\x65mail_is_validated\x18\x02 \x01(\x08\x12 \n\x18\x65mail_validation_changed\x18\x03 \x01(\x08\x12\'\n\x1f\x63redential_change_requires_code\x18\x04 \x01(\x08\x12\x31\n)password_or_secretqa_change_requires_code\x18\x05 \x01(\x08\"\x8b\x01\n\x16\x43MsgCREItemVoteSummary\x12\x43\n\x12published_file_ids\x18\x01 \x03(\x0b\x32\'.CMsgCREItemVoteSummary.PublishedFileId\x1a,\n\x0fPublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\"\xfa\x01\n\x1e\x43MsgCREItemVoteSummaryResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12L\n\x13item_vote_summaries\x18\x02 \x03(\x0b\x32/.CMsgCREItemVoteSummaryResponse.ItemVoteSummary\x1av\n\x0fItemVoteSummary\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x11\n\tvotes_for\x18\x02 \x01(\x05\x12\x15\n\rvotes_against\x18\x03 \x01(\x05\x12\x0f\n\x07reports\x18\x04 \x01(\x05\x12\r\n\x05score\x18\x05 \x01(\x02\"P\n\"CMsgCREUpdateUserPublishedItemVote\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0f\n\x07vote_up\x18\x02 \x01(\x08\"@\n*CMsgCREUpdateUserPublishedItemVoteResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"\xab\x01\n&CMsgCREGetUserPublishedItemVoteDetails\x12S\n\x12published_file_ids\x18\x01 \x03(\x0b\x32\x37.CMsgCREGetUserPublishedItemVoteDetails.PublishedFileId\x1a,\n\x0fPublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\"\xea\x01\n.CMsgCREGetUserPublishedItemVoteDetailsResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x62\n\x16user_item_vote_details\x18\x02 \x03(\x0b\x32\x42.CMsgCREGetUserPublishedItemVoteDetailsResponse.UserItemVoteDetail\x1a@\n\x12UserItemVoteDetail\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0f\n\x04vote\x18\x02 \x01(\x05:\x01\x30\"*\n\x16\x43MsgFSGetFollowerCount\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"F\n\x1e\x43MsgFSGetFollowerCountResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x10\n\x05\x63ount\x18\x02 \x01(\x05:\x01\x30\"(\n\x14\x43MsgFSGetIsFollowing\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"O\n\x1c\x43MsgFSGetIsFollowingResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x1b\n\x0cis_following\x18\x02 \x01(\x08:\x05\x66\x61lse\"3\n\x1c\x43MsgFSEnumerateFollowingList\x12\x13\n\x0bstart_index\x18\x01 \x01(\r\"d\n$CMsgFSEnumerateFollowingListResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x15\n\rtotal_results\x18\x02 \x01(\x05\x12\x11\n\tsteam_ids\x18\x03 \x03(\x06\"0\n\x1f\x43MsgDPGetNumberOfCurrentPlayers\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"S\n\'CMsgDPGetNumberOfCurrentPlayersResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x14\n\x0cplayer_count\x18\x02 \x01(\x05\"a\n#CMsgClientFriendUserStatusPublished\x12\x16\n\x0e\x66riend_steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x13\n\x0bstatus_text\x18\x03 \x01(\t\"h\n\x1d\x43MsgClientServiceMethodLegacy\x12\x13\n\x0bmethod_name\x18\x01 \x01(\t\x12\x19\n\x11serialized_method\x18\x02 \x01(\x0c\x12\x17\n\x0fis_notification\x18\x03 \x01(\x08\"`\n%CMsgClientServiceMethodLegacyResponse\x12\x13\n\x0bmethod_name\x18\x01 \x01(\t\x12\"\n\x1aserialized_method_response\x18\x02 \x01(\x0c\"5\n\x10\x43MsgClientUIMode\x12\x0e\n\x06uimode\x18\x01 \x01(\r\x12\x11\n\tchat_mode\x18\x02 \x01(\r\"<\n&CMsgClientVanityURLChangedNotification\x12\x12\n\nvanity_url\x18\x01 \x01(\t\"y\n%CMsgClientAuthorizeLocalDeviceRequest\x12\x1a\n\x12\x64\x65vice_description\x18\x01 \x01(\t\x12\x18\n\x10owner_account_id\x18\x02 \x01(\r\x12\x1a\n\x12local_device_token\x18\x03 \x01(\x04\"k\n\x1e\x43MsgClientAuthorizeLocalDevice\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x18\n\x10owner_account_id\x18\x02 \x01(\r\x12\x1b\n\x13\x61uthed_device_token\x18\x03 \x01(\x04\"v\n*CMsgClientAuthorizeLocalDeviceNotification\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x18\n\x10owner_account_id\x18\x02 \x01(\r\x12\x1a\n\x12local_device_token\x18\x03 \x01(\x04\"n\n\"CMsgClientDeauthorizeDeviceRequest\x12\"\n\x1a\x64\x65\x61uthorization_account_id\x18\x01 \x01(\r\x12$\n\x1c\x64\x65\x61uthorization_device_token\x18\x02 \x01(\x04\"U\n\x1b\x43MsgClientDeauthorizeDevice\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\"\n\x1a\x64\x65\x61uthorization_account_id\x18\x02 \x01(\r\"\xd1\x01\n&CMsgClientUseLocalDeviceAuthorizations\x12 \n\x18\x61uthorization_account_id\x18\x01 \x03(\r\x12J\n\rdevice_tokens\x18\x02 \x03(\x0b\x32\x33.CMsgClientUseLocalDeviceAuthorizations.DeviceToken\x1a\x39\n\x0b\x44\x65viceToken\x12\x18\n\x10owner_account_id\x18\x01 \x01(\r\x12\x10\n\x08token_id\x18\x02 \x01(\x04\" \n\x1e\x43MsgClientGetAuthorizedDevices\"\xad\x02\n&CMsgClientGetAuthorizedDevicesResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12S\n\x11\x61uthorized_device\x18\x02 \x03(\x0b\x32\x38.CMsgClientGetAuthorizedDevicesResponse.AuthorizedDevice\x1a\x99\x01\n\x10\x41uthorizedDevice\x12\x19\n\x11\x61uth_device_token\x18\x01 \x01(\x04\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x18\n\x10last_access_time\x18\x03 \x01(\r\x12\x13\n\x0b\x62orrower_id\x18\x04 \x01(\r\x12\x12\n\nis_pending\x18\x05 \x01(\x08\x12\x12\n\napp_played\x18\x06 \x01(\r\"\xc2\x01\n!CMsgClientSharedLibraryLockStatus\x12H\n\x0elocked_library\x18\x01 \x03(\x0b\x32\x30.CMsgClientSharedLibraryLockStatus.LockedLibrary\x12\x1d\n\x15own_library_locked_by\x18\x02 \x01(\r\x1a\x34\n\rLockedLibrary\x12\x10\n\x08owner_id\x18\x01 \x01(\r\x12\x11\n\tlocked_by\x18\x02 \x01(\r\"\xa7\x01\n\"CMsgClientSharedLibraryStopPlaying\x12\x14\n\x0cseconds_left\x18\x01 \x01(\x05\x12>\n\tstop_apps\x18\x02 \x03(\x0b\x32+.CMsgClientSharedLibraryStopPlaying.StopApp\x1a+\n\x07StopApp\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x10\n\x08owner_id\x18\x02 \x01(\r\"\x81\x02\n\x15\x43MsgClientServiceCall\x12\x15\n\rsysid_routing\x18\x01 \x01(\x0c\x12\x13\n\x0b\x63\x61ll_handle\x18\x02 \x01(\r\x12\x12\n\nmodule_crc\x18\x03 \x01(\r\x12\x13\n\x0bmodule_hash\x18\x04 \x01(\x0c\x12\x13\n\x0b\x66unction_id\x18\x05 \x01(\r\x12\x16\n\x0e\x63ub_output_max\x18\x06 \x01(\r\x12\r\n\x05\x66lags\x18\x07 \x01(\r\x12\x15\n\rcallparameter\x18\x08 \x01(\x0c\x12\x11\n\tping_only\x18\t \x01(\x08\x12\x1d\n\x15max_outstanding_calls\x18\n \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x0b \x01(\r\"Z\n\x17\x43MsgClientServiceModule\x12\x12\n\nmodule_crc\x18\x01 \x01(\r\x12\x13\n\x0bmodule_hash\x18\x02 \x01(\x0c\x12\x16\n\x0emodule_content\x18\x03 \x01(\x0c\"\xb8\x04\n\x1d\x43MsgClientServiceCallResponse\x12\x15\n\rsysid_routing\x18\x01 \x01(\x0c\x12\x13\n\x0b\x63\x61ll_handle\x18\x02 \x01(\r\x12\x12\n\nmodule_crc\x18\x03 \x01(\r\x12\x13\n\x0bmodule_hash\x18\x04 \x01(\x0c\x12\x13\n\x0b\x65\x63\x61llresult\x18\x05 \x01(\r\x12\x16\n\x0eresult_content\x18\x06 \x01(\x0c\x12\x17\n\x0fos_version_info\x18\x07 \x01(\x0c\x12\x13\n\x0bsystem_info\x18\x08 \x01(\x0c\x12\x14\n\x0cload_address\x18\t \x01(\x06\x12\x18\n\x10\x65xception_record\x18\n \x01(\x0c\x12 \n\x18portable_os_version_info\x18\x0b \x01(\x0c\x12\x1c\n\x14portable_system_info\x18\x0c \x01(\x0c\x12\x15\n\rwas_converted\x18\r \x01(\x08\x12\x17\n\x0finternal_result\x18\x0e \x01(\r\x12\x15\n\rcurrent_count\x18\x0f \x01(\r\x12\x18\n\x10last_call_handle\x18\x10 \x01(\r\x12\x1c\n\x14last_call_module_crc\x18\x11 \x01(\r\x12\x1f\n\x17last_call_sysid_routing\x18\x12 \x01(\x0c\x12\x18\n\x10last_ecallresult\x18\x13 \x01(\r\x12\x1c\n\x14last_callissue_delta\x18\x14 \x01(\r\x12\x1f\n\x17last_callcomplete_delta\x18\x15 \x01(\r\"C\n\x10\x43MsgAMUnlockH264\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08platform\x18\x02 \x01(\x05\x12\x0e\n\x06reason\x18\x03 \x01(\x05\"F\n\x18\x43MsgAMUnlockH264Response\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x16\n\x0e\x65ncryption_key\x18\x02 \x01(\x0c\"M\n\x1d\x43MsgClientPlayingSessionState\x12\x17\n\x0fplaying_blocked\x18\x02 \x01(\x08\x12\x13\n\x0bplaying_app\x18\x03 \x01(\r\"6\n\x1c\x43MsgClientKickPlayingSession\x12\x16\n\x0eonly_stop_game\x18\x01 \x01(\x08\"v\n\x1f\x43MsgClientVoiceCallPreAuthorize\x12\x16\n\x0e\x63\x61ller_steamid\x18\x01 \x01(\x06\x12\x18\n\x10receiver_steamid\x18\x02 \x01(\x06\x12\x11\n\tcaller_id\x18\x03 \x01(\x05\x12\x0e\n\x06hangup\x18\x04 \x01(\x08\"\x82\x01\n\'CMsgClientVoiceCallPreAuthorizeResponse\x12\x16\n\x0e\x63\x61ller_steamid\x18\x01 \x01(\x06\x12\x18\n\x10receiver_steamid\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\x12\x11\n\tcaller_id\x18\x04 \x01(\x05\"B\n\x1c\x43MsgBadgeCraftedNotification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x13\n\x0b\x62\x61\x64ge_level\x18\x02 \x01(\r\"w\n CMsgClientStartPeerContentServer\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10\x63lient_remote_id\x18\x02 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x18\n\x10\x63urrent_build_id\x18\x04 \x01(\r\"\x7f\n(CMsgClientStartPeerContentServerResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x13\n\x0bserver_port\x18\x02 \x01(\r\x12\x18\n\x10installed_depots\x18\x03 \x03(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\x04\"f\n\x1c\x43MsgClientGetPeerContentInfo\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10\x63lient_remote_id\x18\x02 \x01(\x06\x12\x1b\n\x13owned_games_visible\x18\x03 \x01(\x08\"D\n$CMsgClientGetPeerContentInfoResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x0c\n\x04\x61pps\x18\x02 \x03(\r\"-\n\x1b\x43MsgClientPendingGameLaunch\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\"Y\n#CMsgClientPendingGameLaunchResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x0e\n\x06\x65nvkey\x18\x03 \x01(\tB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCLIENTUPDATEUSERGAMEINFO._serialized_start=64
  _CMSGCLIENTUPDATEUSERGAMEINFO._serialized_end=183
  _CMSGCLIENTRICHPRESENCEUPLOAD._serialized_start=185
  _CMSGCLIENTRICHPRESENCEUPLOAD._serialized_end=268
  _CMSGCLIENTRICHPRESENCEREQUEST._serialized_start=270
  _CMSGCLIENTRICHPRESENCEREQUEST._serialized_end=326
  _CMSGCLIENTRICHPRESENCEINFO._serialized_start=329
  _CMSGCLIENTRICHPRESENCEINFO._serialized_end=575
  _CMSGCLIENTRICHPRESENCEINFO_KV._serialized_start=424
  _CMSGCLIENTRICHPRESENCEINFO_KV._serialized_end=456
  _CMSGCLIENTRICHPRESENCEINFO_RICHPRESENCE._serialized_start=458
  _CMSGCLIENTRICHPRESENCEINFO_RICHPRESENCE._serialized_end=575
  _CMSGCLIENTCHECKFILESIGNATURE._serialized_start=577
  _CMSGCLIENTCHECKFILESIGNATURE._serialized_end=623
  _CMSGCLIENTCHECKFILESIGNATURERESPONSE._serialized_start=626
  _CMSGCLIENTCHECKFILESIGNATURERESPONSE._serialized_end=873
  _CMSGCLIENTREGISTERKEY._serialized_start=875
  _CMSGCLIENTREGISTERKEY._serialized_end=911
  _CMSGCLIENTPURCHASERESPONSE._serialized_start=913
  _CMSGCLIENTPURCHASERESPONSE._serialized_end=1025
  _CMSGCLIENTACTIVATEOEMLICENSE._serialized_start=1028
  _CMSGCLIENTACTIVATEOEMLICENSE._serialized_end=1225
  _CMSGCLIENTREGISTEROEMMACHINE._serialized_start=1227
  _CMSGCLIENTREGISTEROEMMACHINE._serialized_end=1284
  _CMSGCLIENTREGISTEROEMMACHINERESPONSE._serialized_start=1286
  _CMSGCLIENTREGISTEROEMMACHINERESPONSE._serialized_end=1341
  _CMSGCLIENTPURCHASEWITHMACHINEID._serialized_start=1343
  _CMSGCLIENTPURCHASEWITHMACHINEID._serialized_end=1418
  _CMSGTRADING_INITIATETRADEREQUEST._serialized_start=1420
  _CMSGTRADING_INITIATETRADEREQUEST._serialized_end=1523
  _CMSGTRADING_INITIATETRADERESPONSE._serialized_start=1526
  _CMSGTRADING_INITIATETRADERESPONSE._serialized_end=1864
  _CMSGTRADING_CANCELTRADEREQUEST._serialized_start=1866
  _CMSGTRADING_CANCELTRADEREQUEST._serialized_end=1921
  _CMSGTRADING_STARTSESSION._serialized_start=1923
  _CMSGTRADING_STARTSESSION._serialized_end=1972
  _CMSGCLIENTGETDEPOTDECRYPTIONKEY._serialized_start=1974
  _CMSGCLIENTGETDEPOTDECRYPTIONKEY._serialized_end=2041
  _CMSGCLIENTGETDEPOTDECRYPTIONKEYRESPONSE._serialized_start=2043
  _CMSGCLIENTGETDEPOTDECRYPTIONKEYRESPONSE._serialized_end=2152
  _CMSGCLIENTCHECKAPPBETAPASSWORD._serialized_start=2154
  _CMSGCLIENTCHECKAPPBETAPASSWORD._serialized_end=2242
  _CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE._serialized_start=2245
  _CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE._serialized_end=2463
  _CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE_BETAPASSWORD._serialized_start=2384
  _CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE_BETAPASSWORD._serialized_end=2463
  _CMSGCLIENTUGSGETGLOBALSTATS._serialized_start=2466
  _CMSGCLIENTUGSGETGLOBALSTATS._serialized_end=2619
  _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE._serialized_start=2622
  _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE._serialized_end=2899
  _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY._serialized_start=2777
  _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY._serialized_end=2899
  _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY_STAT._serialized_start=2862
  _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY_STAT._serialized_end=2899
  _CMSGCLIENTREDEEMGUESTPASS._serialized_start=2901
  _CMSGCLIENTREDEEMGUESTPASS._serialized_end=2951
  _CMSGCLIENTREDEEMGUESTPASSRESPONSE._serialized_start=2953
  _CMSGCLIENTREDEEMGUESTPASSRESPONSE._serialized_end=3052
  _CMSGCLIENTGETCLANACTIVITYCOUNTS._serialized_start=3054
  _CMSGCLIENTGETCLANACTIVITYCOUNTS._serialized_end=3110
  _CMSGCLIENTGETCLANACTIVITYCOUNTSRESPONSE._serialized_start=3112
  _CMSGCLIENTGETCLANACTIVITYCOUNTSRESPONSE._serialized_end=3173
  _CMSGCLIENTOGSREPORTSTRING._serialized_start=3175
  _CMSGCLIENTOGSREPORTSTRING._serialized_end=3296
  _CMSGCLIENTOGSREPORTBUG._serialized_start=3298
  _CMSGCLIENTOGSREPORTBUG._serialized_end=3378
  _CMSGCLIENTSENTLOGS._serialized_start=3380
  _CMSGCLIENTSENTLOGS._serialized_end=3400
  _CMSGGCCLIENT._serialized_start=3403
  _CMSGGCCLIENT._serialized_end=3549
  _CMSGGCCLIENT_EFLAG._serialized_start=3528
  _CMSGGCCLIENT_EFLAG._serialized_end=3549
  _CMSGCLIENTREQUESTFREELICENSE._serialized_start=3551
  _CMSGCLIENTREQUESTFREELICENSE._serialized_end=3597
  _CMSGCLIENTREQUESTFREELICENSERESPONSE._serialized_start=3599
  _CMSGCLIENTREQUESTFREELICENSERESPONSE._serialized_end=3709
  _CMSGDRMDOWNLOADREQUESTWITHCRASHDATA._serialized_start=3712
  _CMSGDRMDOWNLOADREQUESTWITHCRASHDATA._serialized_end=3923
  _CMSGDRMDOWNLOADRESPONSE._serialized_start=3926
  _CMSGDRMDOWNLOADRESPONSE._serialized_end=4145
  _CMSGDRMFINALRESULT._serialized_start=4148
  _CMSGDRMFINALRESULT._serialized_end=4363
  _CMSGCLIENTDPCHECKSPECIALSURVEY._serialized_start=4365
  _CMSGCLIENTDPCHECKSPECIALSURVEY._serialized_end=4416
  _CMSGCLIENTDPCHECKSPECIALSURVEYRESPONSE._serialized_start=4419
  _CMSGCLIENTDPCHECKSPECIALSURVEYRESPONSE._serialized_end=4569
  _CMSGCLIENTDPSENDSPECIALSURVEYRESPONSE._serialized_start=4571
  _CMSGCLIENTDPSENDSPECIALSURVEYRESPONSE._serialized_end=4643
  _CMSGCLIENTDPSENDSPECIALSURVEYRESPONSEREPLY._serialized_start=4645
  _CMSGCLIENTDPSENDSPECIALSURVEYRESPONSEREPLY._serialized_end=4724
  _CMSGCLIENTREQUESTFORGOTTENPASSWORDEMAIL._serialized_start=4726
  _CMSGCLIENTREQUESTFORGOTTENPASSWORDEMAIL._serialized_end=4813
  _CMSGCLIENTREQUESTFORGOTTENPASSWORDEMAILRESPONSE._serialized_start=4815
  _CMSGCLIENTREQUESTFORGOTTENPASSWORDEMAILRESPONSE._serialized_end=4910
  _CMSGCLIENTITEMANNOUNCEMENTS._serialized_start=4913
  _CMSGCLIENTITEMANNOUNCEMENTS._serialized_end=5159
  _CMSGCLIENTITEMANNOUNCEMENTS_UNSEENITEM._serialized_start=5032
  _CMSGCLIENTITEMANNOUNCEMENTS_UNSEENITEM._serialized_end=5159
  _CMSGCLIENTREQUESTITEMANNOUNCEMENTS._serialized_start=5161
  _CMSGCLIENTREQUESTITEMANNOUNCEMENTS._serialized_end=5197
  _CMSGCLIENTUSERNOTIFICATIONS._serialized_start=5200
  _CMSGCLIENTUSERNOTIFICATIONS._serialized_end=5358
  _CMSGCLIENTUSERNOTIFICATIONS_NOTIFICATION._serialized_start=5297
  _CMSGCLIENTUSERNOTIFICATIONS_NOTIFICATION._serialized_end=5358
  _CMSGCLIENTCOMMENTNOTIFICATIONS._serialized_start=5361
  _CMSGCLIENTCOMMENTNOTIFICATIONS._serialized_end=5497
  _CMSGCLIENTREQUESTCOMMENTNOTIFICATIONS._serialized_start=5499
  _CMSGCLIENTREQUESTCOMMENTNOTIFICATIONS._serialized_end=5538
  _CMSGCLIENTOFFLINEMESSAGENOTIFICATION._serialized_start=5540
  _CMSGCLIENTOFFLINEMESSAGENOTIFICATION._serialized_end=5643
  _CMSGCLIENTREQUESTOFFLINEMESSAGECOUNT._serialized_start=5645
  _CMSGCLIENTREQUESTOFFLINEMESSAGECOUNT._serialized_end=5683
  _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORY._serialized_start=5685
  _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORY._serialized_end=5741
  _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE._serialized_start=5744
  _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE._serialized_end=5993
  _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE_FRIENDMESSAGE._serialized_start=5907
  _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE_FRIENDMESSAGE._serialized_end=5993
  _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYFOROFFLINEMESSAGES._serialized_start=5995
  _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYFOROFFLINEMESSAGES._serialized_end=6052
  _CMSGCLIENTFSGETFRIENDSSTEAMLEVELS._serialized_start=6054
  _CMSGCLIENTFSGETFRIENDSSTEAMLEVELS._serialized_end=6109
  _CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE._serialized_start=6112
  _CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE._serialized_end=6267
  _CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE_FRIEND._serialized_start=6225
  _CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE_FRIEND._serialized_end=6267
  _CMSGCLIENTEMAILADDRINFO._serialized_start=6270
  _CMSGCLIENTEMAILADDRINFO._serialized_end=6472
  _CMSGCREITEMVOTESUMMARY._serialized_start=6475
  _CMSGCREITEMVOTESUMMARY._serialized_end=6614
  _CMSGCREITEMVOTESUMMARY_PUBLISHEDFILEID._serialized_start=6570
  _CMSGCREITEMVOTESUMMARY_PUBLISHEDFILEID._serialized_end=6614
  _CMSGCREITEMVOTESUMMARYRESPONSE._serialized_start=6617
  _CMSGCREITEMVOTESUMMARYRESPONSE._serialized_end=6867
  _CMSGCREITEMVOTESUMMARYRESPONSE_ITEMVOTESUMMARY._serialized_start=6749
  _CMSGCREITEMVOTESUMMARYRESPONSE_ITEMVOTESUMMARY._serialized_end=6867
  _CMSGCREUPDATEUSERPUBLISHEDITEMVOTE._serialized_start=6869
  _CMSGCREUPDATEUSERPUBLISHEDITEMVOTE._serialized_end=6949
  _CMSGCREUPDATEUSERPUBLISHEDITEMVOTERESPONSE._serialized_start=6951
  _CMSGCREUPDATEUSERPUBLISHEDITEMVOTERESPONSE._serialized_end=7015
  _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS._serialized_start=7018
  _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS._serialized_end=7189
  _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS_PUBLISHEDFILEID._serialized_start=6570
  _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS_PUBLISHEDFILEID._serialized_end=6614
  _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE._serialized_start=7192
  _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE._serialized_end=7426
  _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE_USERITEMVOTEDETAIL._serialized_start=7362
  _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE_USERITEMVOTEDETAIL._serialized_end=7426
  _CMSGFSGETFOLLOWERCOUNT._serialized_start=7428
  _CMSGFSGETFOLLOWERCOUNT._serialized_end=7470
  _CMSGFSGETFOLLOWERCOUNTRESPONSE._serialized_start=7472
  _CMSGFSGETFOLLOWERCOUNTRESPONSE._serialized_end=7542
  _CMSGFSGETISFOLLOWING._serialized_start=7544
  _CMSGFSGETISFOLLOWING._serialized_end=7584
  _CMSGFSGETISFOLLOWINGRESPONSE._serialized_start=7586
  _CMSGFSGETISFOLLOWINGRESPONSE._serialized_end=7665
  _CMSGFSENUMERATEFOLLOWINGLIST._serialized_start=7667
  _CMSGFSENUMERATEFOLLOWINGLIST._serialized_end=7718
  _CMSGFSENUMERATEFOLLOWINGLISTRESPONSE._serialized_start=7720
  _CMSGFSENUMERATEFOLLOWINGLISTRESPONSE._serialized_end=7820
  _CMSGDPGETNUMBEROFCURRENTPLAYERS._serialized_start=7822
  _CMSGDPGETNUMBEROFCURRENTPLAYERS._serialized_end=7870
  _CMSGDPGETNUMBEROFCURRENTPLAYERSRESPONSE._serialized_start=7872
  _CMSGDPGETNUMBEROFCURRENTPLAYERSRESPONSE._serialized_end=7955
  _CMSGCLIENTFRIENDUSERSTATUSPUBLISHED._serialized_start=7957
  _CMSGCLIENTFRIENDUSERSTATUSPUBLISHED._serialized_end=8054
  _CMSGCLIENTSERVICEMETHODLEGACY._serialized_start=8056
  _CMSGCLIENTSERVICEMETHODLEGACY._serialized_end=8160
  _CMSGCLIENTSERVICEMETHODLEGACYRESPONSE._serialized_start=8162
  _CMSGCLIENTSERVICEMETHODLEGACYRESPONSE._serialized_end=8258
  _CMSGCLIENTUIMODE._serialized_start=8260
  _CMSGCLIENTUIMODE._serialized_end=8313
  _CMSGCLIENTVANITYURLCHANGEDNOTIFICATION._serialized_start=8315
  _CMSGCLIENTVANITYURLCHANGEDNOTIFICATION._serialized_end=8375
  _CMSGCLIENTAUTHORIZELOCALDEVICEREQUEST._serialized_start=8377
  _CMSGCLIENTAUTHORIZELOCALDEVICEREQUEST._serialized_end=8498
  _CMSGCLIENTAUTHORIZELOCALDEVICE._serialized_start=8500
  _CMSGCLIENTAUTHORIZELOCALDEVICE._serialized_end=8607
  _CMSGCLIENTAUTHORIZELOCALDEVICENOTIFICATION._serialized_start=8609
  _CMSGCLIENTAUTHORIZELOCALDEVICENOTIFICATION._serialized_end=8727
  _CMSGCLIENTDEAUTHORIZEDEVICEREQUEST._serialized_start=8729
  _CMSGCLIENTDEAUTHORIZEDEVICEREQUEST._serialized_end=8839
  _CMSGCLIENTDEAUTHORIZEDEVICE._serialized_start=8841
  _CMSGCLIENTDEAUTHORIZEDEVICE._serialized_end=8926
  _CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS._serialized_start=8929
  _CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS._serialized_end=9138
  _CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS_DEVICETOKEN._serialized_start=9081
  _CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS_DEVICETOKEN._serialized_end=9138
  _CMSGCLIENTGETAUTHORIZEDDEVICES._serialized_start=9140
  _CMSGCLIENTGETAUTHORIZEDDEVICES._serialized_end=9172
  _CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE._serialized_start=9175
  _CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE._serialized_end=9476
  _CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE_AUTHORIZEDDEVICE._serialized_start=9323
  _CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE_AUTHORIZEDDEVICE._serialized_end=9476
  _CMSGCLIENTSHAREDLIBRARYLOCKSTATUS._serialized_start=9479
  _CMSGCLIENTSHAREDLIBRARYLOCKSTATUS._serialized_end=9673
  _CMSGCLIENTSHAREDLIBRARYLOCKSTATUS_LOCKEDLIBRARY._serialized_start=9621
  _CMSGCLIENTSHAREDLIBRARYLOCKSTATUS_LOCKEDLIBRARY._serialized_end=9673
  _CMSGCLIENTSHAREDLIBRARYSTOPPLAYING._serialized_start=9676
  _CMSGCLIENTSHAREDLIBRARYSTOPPLAYING._serialized_end=9843
  _CMSGCLIENTSHAREDLIBRARYSTOPPLAYING_STOPAPP._serialized_start=9800
  _CMSGCLIENTSHAREDLIBRARYSTOPPLAYING_STOPAPP._serialized_end=9843
  _CMSGCLIENTSERVICECALL._serialized_start=9846
  _CMSGCLIENTSERVICECALL._serialized_end=10103
  _CMSGCLIENTSERVICEMODULE._serialized_start=10105
  _CMSGCLIENTSERVICEMODULE._serialized_end=10195
  _CMSGCLIENTSERVICECALLRESPONSE._serialized_start=10198
  _CMSGCLIENTSERVICECALLRESPONSE._serialized_end=10766
  _CMSGAMUNLOCKH264._serialized_start=10768
  _CMSGAMUNLOCKH264._serialized_end=10835
  _CMSGAMUNLOCKH264RESPONSE._serialized_start=10837
  _CMSGAMUNLOCKH264RESPONSE._serialized_end=10907
  _CMSGCLIENTPLAYINGSESSIONSTATE._serialized_start=10909
  _CMSGCLIENTPLAYINGSESSIONSTATE._serialized_end=10986
  _CMSGCLIENTKICKPLAYINGSESSION._serialized_start=10988
  _CMSGCLIENTKICKPLAYINGSESSION._serialized_end=11042
  _CMSGCLIENTVOICECALLPREAUTHORIZE._serialized_start=11044
  _CMSGCLIENTVOICECALLPREAUTHORIZE._serialized_end=11162
  _CMSGCLIENTVOICECALLPREAUTHORIZERESPONSE._serialized_start=11165
  _CMSGCLIENTVOICECALLPREAUTHORIZERESPONSE._serialized_end=11295
  _CMSGBADGECRAFTEDNOTIFICATION._serialized_start=11297
  _CMSGBADGECRAFTEDNOTIFICATION._serialized_end=11363
  _CMSGCLIENTSTARTPEERCONTENTSERVER._serialized_start=11365
  _CMSGCLIENTSTARTPEERCONTENTSERVER._serialized_end=11484
  _CMSGCLIENTSTARTPEERCONTENTSERVERRESPONSE._serialized_start=11486
  _CMSGCLIENTSTARTPEERCONTENTSERVERRESPONSE._serialized_end=11613
  _CMSGCLIENTGETPEERCONTENTINFO._serialized_start=11615
  _CMSGCLIENTGETPEERCONTENTINFO._serialized_end=11717
  _CMSGCLIENTGETPEERCONTENTINFORESPONSE._serialized_start=11719
  _CMSGCLIENTGETPEERCONTENTINFORESPONSE._serialized_end=11787
  _CMSGCLIENTPENDINGGAMELAUNCH._serialized_start=11789
  _CMSGCLIENTPENDINGGAMELAUNCH._serialized_end=11834
  _CMSGCLIENTPENDINGGAMELAUNCHRESPONSE._serialized_start=11836
  _CMSGCLIENTPENDINGGAMELAUNCHRESPONSE._serialized_end=11925
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_steamengine.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fwebuimessages_steamengine.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"V\n4CSteamEngine_UpdateTextFilterDictionary_Notification\x12\x10\n\x08language\x18\x01 \x02(\t\x12\x0c\n\x04type\x18\x02 \x02(\t\"N\n,CSteamEngine_GetTextFilterDictionary_Request\x12\x10\n\x08language\x18\x01 \x02(\t\x12\x0c\n\x04type\x18\x02 \x02(\t\"C\n-CSteamEngine_GetTextFilterDictionary_Response\x12\x12\n\ndictionary\x18\x01 \x01(\t\"W\n5CSteamEngine_TextFilterDictionaryChanged_Notification\x12\x10\n\x08language\x18\x01 \x02(\t\x12\x0c\n\x04type\x18\x02 \x02(\t\"3\n$CSteamEngine_GetGameIDForPID_Request\x12\x0b\n\x03pid\x18\x01 \x01(\r\"7\n%CSteamEngine_GetGameIDForPID_Response\x12\x0e\n\x06gameid\x18\x01 \x01(\x04\"^\n5CSteamEngine_SetOverlayEscapeKeyHandling_Notification\x12\x0e\n\x06gameid\x18\x01 \x02(\x04\x12\x15\n\rshould_handle\x18\x02 \x02(\x08\"b\n6CSteamEngine_SearchAppDataCacheByStoreKeywords_Request\x12\x13\n\x0bsearch_term\x18\x01 \x01(\t\x12\x13\n\x0bmax_results\x18\x02 \x01(\r\"I\n7CSteamEngine_SearchAppDataCacheByStoreKeywords_Response\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\r2\xc7\x05\n\x0bSteamEngine\x12\x65\n\x1aUpdateTextFilterDictionary\x12\x35.CSteamEngine_UpdateTextFilterDictionary_Notification\x1a\x10.WebUINoResponse\x12x\n\x17GetTextFilterDictionary\x12-.CSteamEngine_GetTextFilterDictionary_Request\x1a..CSteamEngine_GetTextFilterDictionary_Response\x12m\n!NotifyTextFilterDictionaryChanged\x12\x36.CSteamEngine_TextFilterDictionaryChanged_Notification\x1a\x10.WebUINoResponse\x12`\n\x0fGetGameIDForPID\x12%.CSteamEngine_GetGameIDForPID_Request\x1a&.CSteamEngine_GetGameIDForPID_Response\x12g\n\x1bSetOverlayEscapeKeyHandling\x12\x36.CSteamEngine_SetOverlayEscapeKeyHandling_Notification\x1a\x10.WebUINoResponse\x12\x96\x01\n!SearchAppDataCacheByStoreKeywords\x12\x37.CSteamEngine_SearchAppDataCacheByStoreKeywords_Request\x1a\x38.CSteamEngine_SearchAppDataCacheByStoreKeywords_Response\x1a\x04\x80\x97\"\x02\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_steamengine_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _STEAMENGINE._options = None
  _STEAMENGINE._serialized_options = b'\200\227\"\002'
  _CSTEAMENGINE_UPDATETEXTFILTERDICTIONARY_NOTIFICATION._serialized_start=87
  _CSTEAMENGINE_UPDATETEXTFILTERDICTIONARY_NOTIFICATION._serialized_end=173
  _CSTEAMENGINE_GETTEXTFILTERDICTIONARY_REQUEST._serialized_start=175
  _CSTEAMENGINE_GETTEXTFILTERDICTIONARY_REQUEST._serialized_end=253
  _CSTEAMENGINE_GETTEXTFILTERDICTIONARY_RESPONSE._serialized_start=255
  _CSTEAMENGINE_GETTEXTFILTERDICTIONARY_RESPONSE._serialized_end=322
  _CSTEAMENGINE_TEXTFILTERDICTIONARYCHANGED_NOTIFICATION._serialized_start=324
  _CSTEAMENGINE_TEXTFILTERDICTIONARYCHANGED_NOTIFICATION._serialized_end=411
  _CSTEAMENGINE_GETGAMEIDFORPID_REQUEST._serialized_start=413
  _CSTEAMENGINE_GETGAMEIDFORPID_REQUEST._serialized_end=464
  _CSTEAMENGINE_GETGAMEIDFORPID_RESPONSE._serialized_start=466
  _CSTEAMENGINE_GETGAMEIDFORPID_RESPONSE._serialized_end=521
  _CSTEAMENGINE_SETOVERLAYESCAPEKEYHANDLING_NOTIFICATION._serialized_start=523
  _CSTEAMENGINE_SETOVERLAYESCAPEKEYHANDLING_NOTIFICATION._serialized_end=617
  _CSTEAMENGINE_SEARCHAPPDATACACHEBYSTOREKEYWORDS_REQUEST._serialized_start=619
  _CSTEAMENGINE_SEARCHAPPDATACACHEBYSTOREKEYWORDS_REQUEST._serialized_end=717
  _CSTEAMENGINE_SEARCHAPPDATACACHEBYSTOREKEYWORDS_RESPONSE._serialized_start=719
  _CSTEAMENGINE_SEARCHAPPDATACACHEBYSTOREKEYWORDS_RESPONSE._serialized_end=792
  _STEAMENGINE._serialized_start=795
  _STEAMENGINE._serialized_end=1506
_builder.BuildServices(DESCRIPTOR, 'webuimessages_steamengine_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_mms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$steammessages_clientserver_mms.proto\x1a\x18steammessages_base.proto\"\x98\x01\n\'CMsgClientMMSSetRatelimitPolicyOnClient\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x1a\n\x12\x65nable_rate_limits\x18\x02 \x01(\x08\x12\x1b\n\x13seconds_per_message\x18\x03 \x01(\x05\x12$\n\x1cmilliseconds_per_data_update\x18\x04 \x01(\x05\"\x87\x02\n\x18\x43MsgClientMMSCreateLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x13\n\x0bmax_members\x18\x02 \x01(\x05\x12\x12\n\nlobby_type\x18\x03 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x04 \x01(\x05\x12\x0f\n\x07\x63\x65ll_id\x18\x05 \x01(\r\x12\x1c\n\x14\x64\x65precated_public_ip\x18\x06 \x01(\r\x12\x10\n\x08metadata\x18\x07 \x01(\x0c\x12\x1a\n\x12persona_name_owner\x18\x08 \x01(\t\x12!\n\tpublic_ip\x18\t \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x1d\n\x15network_ping_location\x18\n \x01(\t\"^\n CMsgClientMMSCreateLobbyResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\"\x86\x01\n\x16\x43MsgClientMMSJoinLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x03 \x01(\t\x12\x1d\n\x15network_ping_location\x18\x04 \x01(\t\x12\x0f\n\x07\x63\x65ll_id\x18\x05 \x01(\r\"\xcf\x02\n\x1e\x43MsgClientMMSJoinLobbyResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12 \n\x18\x63hat_room_enter_response\x18\x03 \x01(\x05\x12\x13\n\x0bmax_members\x18\x04 \x01(\x05\x12\x12\n\nlobby_type\x18\x05 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x06 \x01(\x05\x12\x16\n\x0esteam_id_owner\x18\x07 \x01(\x06\x12\x10\n\x08metadata\x18\x08 \x01(\x0c\x12\x37\n\x07members\x18\t \x03(\x0b\x32&.CMsgClientMMSJoinLobbyResponse.Member\x1a\x42\n\x06Member\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\"A\n\x17\x43MsgClientMMSLeaveLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\"]\n\x1f\x43MsgClientMMSLeaveLobbyResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\"\xbf\x02\n\x19\x43MsgClientMMSGetLobbyList\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x1d\n\x15num_lobbies_requested\x18\x03 \x01(\x05\x12\x0f\n\x07\x63\x65ll_id\x18\x04 \x01(\r\x12\x1c\n\x14\x64\x65precated_public_ip\x18\x05 \x01(\r\x12\x32\n\x07\x66ilters\x18\x06 \x03(\x0b\x32!.CMsgClientMMSGetLobbyList.Filter\x12!\n\tpublic_ip\x18\x07 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x1d\n\x15network_ping_location\x18\x08 \x01(\t\x1aN\n\x06\x46ilter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x13\n\x0b\x63omparision\x18\x03 \x01(\x05\x12\x13\n\x0b\x66ilter_type\x18\x04 \x01(\x05\"\xc9\x02\n!CMsgClientMMSGetLobbyListResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\x12\x39\n\x07lobbies\x18\x04 \x03(\x0b\x32(.CMsgClientMMSGetLobbyListResponse.Lobby\x1a\xc4\x01\n\x05Lobby\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x13\n\x0bmax_members\x18\x02 \x01(\x05\x12\x12\n\nlobby_type\x18\x03 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x04 \x01(\x05\x12\x10\n\x08metadata\x18\x05 \x01(\x0c\x12\x13\n\x0bnum_members\x18\x06 \x01(\x05\x12\x10\n\x08\x64istance\x18\x07 \x01(\x02\x12\x0e\n\x06weight\x18\x08 \x01(\x03\x12\x0c\n\x04ping\x18\t \x01(\x05\x12\x14\n\x0cmissing_ping\x18\n \x01(\x05\"\xcb\x01\n\x19\x43MsgClientMMSSetLobbyData\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_member\x18\x03 \x01(\x06\x12\x13\n\x0bmax_members\x18\x04 \x01(\x05\x12\x12\n\nlobby_type\x18\x05 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x06 \x01(\x05\x12\x10\n\x08metadata\x18\x07 \x01(\x0c\x12\x1d\n\x15network_ping_location\x18\x08 \x01(\t\"_\n!CMsgClientMMSSetLobbyDataResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\"C\n\x19\x43MsgClientMMSGetLobbyData\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\"\x80\x03\n\x16\x43MsgClientMMSLobbyData\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x13\n\x0bnum_members\x18\x03 \x01(\x05\x12\x13\n\x0bmax_members\x18\x04 \x01(\x05\x12\x12\n\nlobby_type\x18\x05 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x06 \x01(\x05\x12\x16\n\x0esteam_id_owner\x18\x07 \x01(\x06\x12\x10\n\x08metadata\x18\x08 \x01(\x0c\x12/\n\x07members\x18\t \x03(\x0b\x32\x1e.CMsgClientMMSLobbyData.Member\x12\x14\n\x0clobby_cellid\x18\n \x01(\r\x12#\n\x1bowner_should_accept_changes\x18\x0b \x01(\x08\x1aU\n\x06Member\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\x12\x11\n\tping_data\x18\x04 \x01(\t\"w\n\x1d\x43MsgClientMMSSendLobbyChatMsg\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_target\x18\x03 \x01(\x06\x12\x15\n\rlobby_message\x18\x04 \x01(\x0c\"s\n\x19\x43MsgClientMMSLobbyChatMsg\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_sender\x18\x03 \x01(\x06\x12\x15\n\rlobby_message\x18\x04 \x01(\x0c\"`\n\x1a\x43MsgClientMMSSetLobbyOwner\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x1a\n\x12steam_id_new_owner\x18\x03 \x01(\x06\"`\n\"CMsgClientMMSSetLobbyOwnerResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\"^\n\x1b\x43MsgClientMMSSetLobbyLinked\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_lobby2\x18\x03 \x01(\x06\"\xeb\x01\n\x1f\x43MsgClientMMSSetLobbyGameServer\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12!\n\x19\x64\x65precated_game_server_ip\x18\x03 \x01(\r\x12\x18\n\x10game_server_port\x18\x04 \x01(\r\x12\x1c\n\x14game_server_steam_id\x18\x05 \x01(\x06\x12&\n\x0egame_server_ip\x18\x06 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x1d\n\x15network_ping_location\x18\x07 \x01(\t\"\xcc\x01\n\x1f\x43MsgClientMMSLobbyGameServerSet\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12!\n\x19\x64\x65precated_game_server_ip\x18\x03 \x01(\r\x12\x18\n\x10game_server_port\x18\x04 \x01(\r\x12\x1c\n\x14game_server_steam_id\x18\x05 \x01(\x06\x12&\n\x0egame_server_ip\x18\x06 \x01(\x0b\x32\x0e.CMsgIPAddress\"s\n\x1c\x43MsgClientMMSUserJoinedLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x15\n\rsteam_id_user\x18\x03 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x04 \x01(\t\"q\n\x1a\x43MsgClientMMSUserLeftLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x15\n\rsteam_id_user\x18\x03 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x04 \x01(\t\"c\n\x1a\x43MsgClientMMSInviteToLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x1d\n\x15steam_id_user_invited\x18\x03 \x01(\x06\"x\n\x1b\x43MsgClientMMSGetLobbyStatus\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x18\n\x10\x63laim_membership\x18\x03 \x01(\x08\x12\x17\n\x0f\x63laim_ownership\x18\x04 \x01(\x08\"\x8f\x01\n#CMsgClientMMSGetLobbyStatusResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12@\n\x0clobby_status\x18\x03 \x01(\x0e\x32\x10.EMMSLobbyStatus:\x18k_EMMSLobbyStatusInvalid*\x90\x01\n\x0f\x45MMSLobbyStatus\x12\x1c\n\x18k_EMMSLobbyStatusInvalid\x10\x00\x12\x1b\n\x17k_EMMSLobbyStatusExists\x10\x01\x12!\n\x1dk_EMMSLobbyStatusDoesNotExist\x10\x02\x12\x1f\n\x1bk_EMMSLobbyStatusNotAMember\x10\x03\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_mms_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _EMMSLOBBYSTATUS._serialized_start=4210
  _EMMSLOBBYSTATUS._serialized_end=4354
  _CMSGCLIENTMMSSETRATELIMITPOLICYONCLIENT._serialized_start=67
  _CMSGCLIENTMMSSETRATELIMITPOLICYONCLIENT._serialized_end=219
  _CMSGCLIENTMMSCREATELOBBY._serialized_start=222
  _CMSGCLIENTMMSCREATELOBBY._serialized_end=485
  _CMSGCLIENTMMSCREATELOBBYRESPONSE._serialized_start=487
  _CMSGCLIENTMMSCREATELOBBYRESPONSE._serialized_end=581
  _CMSGCLIENTMMSJOINLOBBY._serialized_start=584
  _CMSGCLIENTMMSJOINLOBBY._serialized_end=718
  _CMSGCLIENTMMSJOINLOBBYRESPONSE._serialized_start=721
  _CMSGCLIENTMMSJOINLOBBYRESPONSE._serialized_end=1056
  _CMSGCLIENTMMSJOINLOBBYRESPONSE_MEMBER._serialized_start=990
  _CMSGCLIENTMMSJOINLOBBYRESPONSE_MEMBER._serialized_end=1056
  _CMSGCLIENTMMSLEAVELOBBY._serialized_start=1058
  _CMSGCLIENTMMSLEAVELOBBY._serialized_end=1123
  _CMSGCLIENTMMSLEAVELOBBYRESPONSE._serialized_start=1125
  _CMSGCLIENTMMSLEAVELOBBYRESPONSE._serialized_end=1218
  _CMSGCLIENTMMSGETLOBBYLIST._serialized_start=1221
  _CMSGCLIENTMMSGETLOBBYLIST._serialized_end=1540
  _CMSGCLIENTMMSGETLOBBYLIST_FILTER._serialized_start=1462
  _CMSGCLIENTMMSGETLOBBYLIST_FILTER._serialized_end=1540
  _CMSGCLIENTMMSGETLOBBYLISTRESPONSE._serialized_start=1543
  _CMSGCLIENTMMSGETLOBBYLISTRESPONSE._serialized_end=1872
  _CMSGCLIENTMMSGETLOBBYLISTRESPONSE_LOBBY._serialized_start=1676
  _CMSGCLIENTMMSGETLOBBYLISTRESPONSE_LOBBY._serialized_end=1872
  _CMSGCLIENTMMSSETLOBBYDATA._serialized_start=1875
  _CMSGCLIENTMMSSETLOBBYDATA._serialized_end=2078
  _CMSGCLIENTMMSSETLOBBYDATARESPONSE._serialized_start=2080
  _CMSGCLIENTMMSSETLOBBYDATARESPONSE._serialized_end=2175
  _CMSGCLIENTMMSGETLOBBYDATA._serialized_start=2177
  _CMSGCLIENTMMSGETLOBBYDATA._serialized_end=2244
  _CMSGCLIENTMMSLOBBYDATA._serialized_start=2247
  _CMSGCLIENTMMSLOBBYDATA._serialized_end=2631
  _CMSGCLIENTMMSLOBBYDATA_MEMBER._serialized_start=2546
  _CMSGCLIENTMMSLOBBYDATA_MEMBER._serialized_end=2631
  _CMSGCLIENTMMSSENDLOBBYCHATMSG._serialized_start=2633
  _CMSGCLIENTMMSSENDLOBBYCHATMSG._serialized_end=2752
  _CMSGCLIENTMMSLOBBYCHATMSG._serialized_start=2754
  _CMSGCLIENTMMSLOBBYCHATMSG._serialized_end=2869
  _CMSGCLIENTMMSSETLOBBYOWNER._serialized_start=2871
  _CMSGCLIENTMMSSETLOBBYOWNER._serialized_end=2967
  _CMSGCLIENTMMSSETLOBBYOWNERRESPONSE._serialized_start=2969
  _CMSGCLIENTMMSSETLOBBYOWNERRESPONSE._serialized_end=3065
  _CMSGCLIENTMMSSETLOBBYLINKED._serialized_start=3067
  _CMSGCLIENTMMSSETLOBBYLINKED._serialized_end=3161
  _CMSGCLIENTMMSSETLOBBYGAMESERVER._serialized_start=3164
  _CMSGCLIENTMMSSETLOBBYGAMESERVER._serialized_end=3399
  _CMSGCLIENTMMSLOBBYGAMESERVERSET._serialized_start=3402
  _CMSGCLIENTMMSLOBBYGAMESERVERSET._serialized_end=3606
  _CMSGCLIENTMMSUSERJOINEDLOBBY._serialized_start=3608
  _CMSGCLIENTMMSUSERJOINEDLOBBY._serialized_end=3723
  _CMSGCLIENTMMSUSERLEFTLOBBY._serialized_start=3725
  _CMSGCLIENTMMSUSERLEFTLOBBY._serialized_end=3838
  _CMSGCLIENTMMSINVITETOLOBBY._serialized_start=3840
  _CMSGCLIENTMMSINVITETOLOBBY._serialized_end=3939
  _CMSGCLIENTMMSGETLOBBYSTATUS._serialized_start=3941
  _CMSGCLIENTMMSGETLOBBYSTATUS._serialized_end=4061
  _CMSGCLIENTMMSGETLOBBYSTATUSRESPONSE._serialized_start=4064
  _CMSGCLIENTMMSGETLOBBYSTATUSRESPONSE._serialized_end=4207
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_secrets.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsteammessages_secrets.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\x9b\x01\n\x12\x43KeyEscrow_Request\x12\x1b\n\x13rsa_oaep_sha_ticket\x18\x01 \x01(\x0c\x12\x10\n\x08password\x18\x02 \x01(\x0c\x12\x41\n\x05usage\x18\x03 \x01(\x0e\x32\x10.EKeyEscrowUsage: k_EKeyEscrowUsageStreamingDevice\x12\x13\n\x0b\x64\x65vice_name\x18\x04 \x01(\t\"\x82\x02\n\x11\x43KeyEscrow_Ticket\x12\x10\n\x08password\x18\x01 \x01(\x0c\x12\x12\n\nidentifier\x18\x02 \x01(\x04\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\r\x12\x41\n\x05usage\x18\x05 \x01(\x0e\x32\x10.EKeyEscrowUsage: k_EKeyEscrowUsageStreamingDevice\x12\x13\n\x0b\x64\x65vice_name\x18\x06 \x01(\t\x12\x14\n\x0c\x64\x65vice_model\x18\x07 \x01(\t\x12\x15\n\rdevice_serial\x18\x08 \x01(\t\x12\x1e\n\x16\x64\x65vice_provisioning_id\x18\t \x01(\r\"9\n\x13\x43KeyEscrow_Response\x12\"\n\x06ticket\x18\x01 \x01(\x0b\x32\x12.CKeyEscrow_Ticket*7\n\x0f\x45KeyEscrowUsage\x12$\n k_EKeyEscrowUsageStreamingDevice\x10\x00\x32\x41\n\x07Secrets\x12\x36\n\tKeyEscrow\x12\x13.CKeyEscrow_Request\x1a\x14.CKeyEscrow_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_secrets_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _EKEYESCROWUSAGE._serialized_start=569
  _EKEYESCROWUSAGE._serialized_end=624
  _CKEYESCROW_REQUEST._serialized_start=92
  _CKEYESCROW_REQUEST._serialized_end=247
  _CKEYESCROW_TICKET._serialized_start=250
  _CKEYESCROW_TICKET._serialized_end=508
  _CKEYESCROW_RESPONSE._serialized_start=510
  _CKEYESCROW_RESPONSE._serialized_end=567
  _SECRETS._serialized_start=626
  _SECRETS._serialized_end=691
_builder.BuildServices(DESCRIPTOR, 'steammessages_secrets_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_transport.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dwebuimessages_transport.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"7\n#CTransportAuth_Authenticate_Request\x12\x10\n\x08\x61uth_key\x18\x01 \x01(\t\"&\n$CTransportAuth_Authenticate_Response\"+\n)CTransportAuth_StartShutdown_Notification2\xc7\x01\n\rTransportAuth\x12[\n\x0c\x41uthenticate\x12$.CTransportAuth_Authenticate_Request\x1a%.CTransportAuth_Authenticate_Response\x12S\n\x13NotifyStartShutdown\x12*.CTransportAuth_StartShutdown_Notification\x1a\x10.WebUINoResponse\x1a\x04\x80\x97\"\x03\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_transport_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _TRANSPORTAUTH._options = None
  _TRANSPORTAUTH._serialized_options = b'\200\227\"\003'
  _CTRANSPORTAUTH_AUTHENTICATE_REQUEST._serialized_start=85
  _CTRANSPORTAUTH_AUTHENTICATE_REQUEST._serialized_end=140
  _CTRANSPORTAUTH_AUTHENTICATE_RESPONSE._serialized_start=142
  _CTRANSPORTAUTH_AUTHENTICATE_RESPONSE._serialized_end=180
  _CTRANSPORTAUTH_STARTSHUTDOWN_NOTIFICATION._serialized_start=182
  _CTRANSPORTAUTH_STARTSHUTDOWN_NOTIFICATION._serialized_end=225
  _TRANSPORTAUTH._serialized_start=228
  _TRANSPORTAUTH._serialized_end=427
_builder.BuildServices(DESCRIPTOR, 'webuimessages_transport_pb2', globals())
# @@protoc_insertion_point(module_scope)
